@@ -1,7 +1,6 @@
 import click
 
-from mobt.MobApp.EndMob import EndMob
-from mobt.di import di
+from mobt import echo
 
 
 @click.command()
@@ -13,6 +12,8 @@ def done(ctx):
         It will remove the mob session file, squash all the commits and push all the changes to the remote.
         All git hooks will be executed for this final commit.
     """
+    from mobt.di import di
+    from mobt.MobApp.EndMob import EndMob
     di.get(EndMob).end()
 
-    click.secho(f'Done!', fg='green')
+    echo(f'Done!', fg='green')
