@@ -54,6 +54,12 @@ def start(branch_name: BranchName, members: str = None, reset_members: bool = Fa
         # We need to convert it to a list of TeamMemberName
         members = TeamMembers([TeamMemberName(n.strip()) for n in members.split(',') if n and n.strip()])
 
+    if members is None:
+        from mobt.SessionSettings.SessionSettingsService import SessionSettingsService
+        session_settings_service: SessionSettingsService = di.get(SessionSettingsService)
+        session_settings = session_settings_service.find()
+        members = session_settings.team if session_settings else None
+
     if members is None:
         # Members were not passed as a parameter, or it's an empty list. Load the last team members used.
         members = last_team_members_service.get_last_team()
@@ -77,9 +83,7 @@ def start(branch_name: BranchName, members: str = None, reset_members: bool = Fa
 
     di.get(TimerService).start(session_settings.rotation.driverInMinutes)
 
-    echo(f'Your driver round is over. Now you should run `mobt next`.', fg='bright_blue')
-
-    def _make_laptop_speak(text: str):
+    def _make_it_speak(text: str):
         import platform
         if platform.system() == 'Darwin':
             subprocess.call(['say', text])
@@ -88,12 +92,15 @@ def start(branch_name: BranchName, members: str = None, reset_members: bool = Fa
         else:
             print("\a")
 
-    import asyncio
-    async def async_functions():
-        loop = asyncio.get_running_loop()
-        await asyncio.gather(
-            loop.run_in_executor(None, lambda: _make_laptop_speak("Mob Rotate!")),
-        )
+    from mobt.Controllers import controllers_logger
 
-    asyncio.run(async_functions())
-    di.get(GuiService).show_message("Time's up!")
+    try:
+        _make_it_speak("Mob Rotate!")
+    except Exception as e:
+        controllers_logger().error(f'Error while trying to make it speak: {e}')
+    try:
+        di.get(GuiService).show_message("Your driver round is over.\nNow you should run `mobt next`.")
+    except Exception as e:
+        controllers_logger().error(f'Error while trying to show the GUI message: {e}')
+
+    echo(f'Your driver round is over. Now you should run `mobt next`.', fg='bright_blue')
